package com.offcn.imclient.ui;

import android.animation.ObjectAnimator;
import android.animation.ValueAnimator;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Handler;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;

import com.google.android.material.tabs.TabLayout;
import com.jyall.base.adapter.BaseVPAdapter;
import com.jyall.base.base.BaseActivity;
import com.jyall.base.util.CommonUtils;
import com.offcn.imclient.R;
import com.offcn.imclient.bean.UserBean;
import com.offcn.imclient.util.LoginManager;
import com.offcn.imclient.util.UserBeanDaoManager;
import com.offcn.live.im.OIMCallback;
import com.offcn.live.im.OIMSDK;
import com.offcn.live.im.bean.OIMCode;
import com.offcn.live.im.util.ZGLCommonUtils;
import com.offcn.live.im.util.ZGLLogUtils;
import com.offcn.live.imkit.ui.ChatListFragment;
import com.offcn.live.imkit.view.ScrollEnabledViewPager;

import java.util.ArrayList;
import java.util.List;

import androidx.fragment.app.Fragment;
import androidx.viewpager.widget.ViewPager;

/**
 * tab主页。由最近会话和好友列表组成
 */
public class MainActivity extends BaseActivity {
    private static final String TAG = MainActivity.class.getSimpleName();

    TabLayout mTabLayout;
    ScrollEnabledViewPager mViewPager;

    String[] titles = new String[]{"聊天", "通讯录", "我的"};

    private UserBean mUserBean;

    @Override
    protected int getContentViewLayoutId() {
        return R.layout.activity_main;
    }

    @Override
    protected void initViewsAndEvents() {

        mTabLayout = findViewById(R.id.tab_layout);
        mViewPager = findViewById(R.id.view_pager);

        mUserBean = LoginManager.getUser(this);
        if (mUserBean == null) {
            CommonUtils.showToast(this, "用户信息获取失败");
            finish();
            return;
        }

        OIMSDK.getInstance().connect(mUserBean.getUser_id(), mUserBean.getToken(), new OIMCallback.OnConnectListener() {
            @Override
            public void onStateConnected() {
                ZGLLogUtils.e(TAG, "IM连接成功");
//                ZGLCommonUtils.showToast(MainActivity.this, "IM连接成功");
            }

            @Override
            public void onStateDisconnected(int code, String error) {
                ZGLLogUtils.e(TAG, "IM连接失败 " + code + " " + error);
                ZGLCommonUtils.showToast(MainActivity.this, "IM连接失败 " + code + " " + error);
                // 连接失败超时，和部分情况作特殊处理如退出页面：token失效、被踢
                if (code == OIMCode.Code_IM_Connect_Fail
                        || code == OIMCode.Code_IM_Connect_Timeout
                        || code == OIMCode.Code_IM_Error_TokenInvalid
                        || code == OIMCode.Code_IM_Disconnect_Kick
                        || code == OIMCode.Code_IM_Error_NoExist) {

                    // 此处注释。内部已调用 destroy() 方法。
//                    OIMSDK.getInstance(DemoMainActivity.this).destroy();
                    // 注销登录信息
                    LoginManager.logout(MainActivity.this);
                    UserBeanDaoManager.getInstance().deleteAll();

                    AlertDialog dialog = new AlertDialog.Builder(MainActivity.this)
                            .setTitle("IM连接失败")
                            .setMessage(code + "," + error)
                            .setPositiveButton("退出", new DialogInterface.OnClickListener() {
                                @Override
                                public void onClick(DialogInterface dialog, int which) {
                                    startActivity(new Intent(MainActivity.this, LoginActivity.class));
                                    finish();
                                }
                            })
                            .setCancelable(false)
                            .create();
                    dialog.setCanceledOnTouchOutside(false);
                    dialog.show();
                }
            }

            @Override
            public void onStateReconnecting() {
                ZGLLogUtils.e(TAG, "IM重连");
            }
        });


        List<Fragment> fragmentList = new ArrayList<>();
        fragmentList.add(new ChatListFragmentWrapper());
        fragmentList.add(new ContactListFragment());
        fragmentList.add(new MeFragment());
        for (int i = 0; i < titles.length; i++) {
            mTabLayout.addTab(mTabLayout.newTab());
        }
        BaseVPAdapter adapter = new BaseVPAdapter(getSupportFragmentManager(), fragmentList);
        mViewPager.setOffscreenPageLimit(fragmentList.size());
        mViewPager.setAdapter(adapter);
        mViewPager.setPagingEnabled(false);
        for (int i = 0; i < titles.length; i++) {
            mTabLayout.getTabAt(i).setCustomView(getTabView(i));
        }

        /**
         * 设置TabLayout的选中监听
         */
        mTabLayout.addOnTabSelectedListener(new TabLayout.OnTabSelectedListener() {

            @Override
            public void onTabSelected(TabLayout.Tab tab) {
                mViewPager.setCurrentItem(tab.getPosition());
                changeTabSelect(tab);   //Tab获取焦点
            }

            @Override
            public void onTabUnselected(TabLayout.Tab tab) {
                changeTabNormal(tab);   //Tab失去焦点
            }

            @Override
            public void onTabReselected(TabLayout.Tab tab) {

            }
        });
    }

    @Override
    protected void loadData() {

    }

    @Override
    protected void onResume() {
        super.onResume();

        // 清除通知栏消息
        OIMSDK.getInstance().clearNotification();
    }

    @Override
    public void onBackPressed() {
//        super.onBackPressed();
        Intent intent = new Intent(Intent.ACTION_MAIN);
        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        intent.addCategory(Intent.CATEGORY_HOME);
        startActivity(intent);
    }

    private View getTabView(int index) {
        View view = LayoutInflater.from(this).inflate(R.layout.item_tab, null);
        TextView title = (TextView) view.findViewById(R.id.tv_title);
        ImageView iv = (ImageView) view.findViewById(R.id.iv_pic);
        title.setText(titles[index]);
        if (index == 0) {
            iv.setImageResource(R.mipmap.ic_chat_tab_on);
            title.setTextColor(getResources().getColor(R.color.colorPrimary));
        } else if (index == 1) {
            iv.setImageResource(R.mipmap.ic_contact_tab_off);
            title.setTextColor(getResources().getColor(R.color.color_333333));
        } else if (index == 2) {
            iv.setImageResource(R.mipmap.ic_me_off);
            title.setTextColor(getResources().getColor(R.color.color_333333));
        }
        return view;
    }

    private void changeTabSelect(TabLayout.Tab tab) {
        final View view = tab.getCustomView();
        int index = tab.getPosition();
        TextView title = (TextView) view.findViewById(R.id.tv_title);
        ImageView iv = (ImageView) view.findViewById(R.id.iv_pic);
        title.setText(titles[index]);
        setTabView(true, index, title, iv);
    }

    /**
     * 改变TabLayout的View到未选中状态
     */
    private void changeTabNormal(TabLayout.Tab tab) {
        final View view = tab.getCustomView();
        int index = tab.getPosition();
        TextView title = (TextView) view.findViewById(R.id.tv_title);
        ImageView iv = (ImageView) view.findViewById(R.id.iv_pic);
        title.setText(titles[index]);
        setTabView(false, index, title, iv);
    }

    private void setTabView(boolean isSelected, int index, TextView title, ImageView iv) {
        switch (index) {
            case 0:
                if (isSelected) {
                    iv.setImageResource(R.mipmap.ic_chat_tab_on);
                    title.setTextColor(getResources().getColor(R.color.colorPrimary));
                } else {
                    iv.setImageResource(R.mipmap.ic_chat_tab_off);
                    title.setTextColor(getResources().getColor(R.color.color_333333));
                }
                break;
            case 1:
                if (isSelected) {
                    iv.setImageResource(R.mipmap.ic_contact_tab_on);
                    title.setTextColor(getResources().getColor(R.color.colorPrimary));
                } else {
                    iv.setImageResource(R.mipmap.ic_contact_tab_off);
                    title.setTextColor(getResources().getColor(R.color.color_333333));
                }
                break;
            case 2:
                if (isSelected) {
                    iv.setImageResource(R.mipmap.ic_me_on);
                    title.setTextColor(getResources().getColor(R.color.colorPrimary));
                } else {
                    iv.setImageResource(R.mipmap.ic_me_off);
                    title.setTextColor(getResources().getColor(R.color.color_333333));
                }
                break;
        }
    }


}
